Documentation
¶
Index ¶
- type BitmaskMobile
- func (bm *BitmaskMobile) GetAllBridges(location, port, transport, transportType string) (_ string, err error)
- func (bm *BitmaskMobile) GetAllGateways(location, port, transport string) (_ string, err error)
- func (bm *BitmaskMobile) GetGeolocation() (_ string, err error)
- func (bm *BitmaskMobile) GetIntroducerURLByDomain(domain string) (_ string, err error)
- func (bm *BitmaskMobile) GetOpenVPNCert() (_ string, err error)
- func (bm *BitmaskMobile) GetProvider() (_ string, err error)
- func (bm *BitmaskMobile) GetService() (_ string, err error)
- func (bm *BitmaskMobile) SetCountryCode(cc string) error
- func (bm *BitmaskMobile) SetCountryCodeLookupURL(urlString string) (err error)
- func (bm *BitmaskMobile) SetDebug(isDebug bool)
- func (bm *BitmaskMobile) SetIntroducer(introducerUrl string) (err error)
- func (bm *BitmaskMobile) SetResolveWithDoH(resolveWithDoH bool) error
- func (bm *BitmaskMobile) SetSocksProxy(proxyUrl string) error
- func (bm *BitmaskMobile) SetStunServers(servers string) (err error)
- func (bm *BitmaskMobile) SetUseTls(useTls bool) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BitmaskMobile ¶
type BitmaskMobile struct {
// contains filtered or unexported fields
}
func NewBitmaskMobile ¶
func NewBitmaskMobile(url string, store mobilemodels.Store) (_ *BitmaskMobile, err error)
func NewBitmaskMobileWithStore ¶
func NewBitmaskMobileWithStore(store mobilemodels.Store) (_ *BitmaskMobile, err error)
func (*BitmaskMobile) GetAllBridges ¶
func (bm *BitmaskMobile) GetAllBridges(location, port, transport, transportType string) (_ string, err error)
func (*BitmaskMobile) GetAllGateways ¶
func (bm *BitmaskMobile) GetAllGateways(location, port, transport string) (_ string, err error)
func (*BitmaskMobile) GetGeolocation ¶
func (bm *BitmaskMobile) GetGeolocation() (_ string, err error)
func (*BitmaskMobile) GetIntroducerURLByDomain ¶
func (bm *BitmaskMobile) GetIntroducerURLByDomain(domain string) (_ string, err error)
func (*BitmaskMobile) GetOpenVPNCert ¶
func (bm *BitmaskMobile) GetOpenVPNCert() (_ string, err error)
func (*BitmaskMobile) GetProvider ¶
func (bm *BitmaskMobile) GetProvider() (_ string, err error)
GetProvider returns the essential provider infos, including urls to the API and supported API version
func (*BitmaskMobile) GetService ¶
func (bm *BitmaskMobile) GetService() (_ string, err error)
GetService returns service information, including available locations and common tunnel config
func (*BitmaskMobile) SetCountryCode ¶
func (bm *BitmaskMobile) SetCountryCode(cc string) error
func (*BitmaskMobile) SetCountryCodeLookupURL ¶
func (bm *BitmaskMobile) SetCountryCodeLookupURL(urlString string) (err error)
SetCountryCodeLookupURL sets the URL for the countrycode lookup service
func (*BitmaskMobile) SetDebug ¶
func (bm *BitmaskMobile) SetDebug(isDebug bool)
SetDebug enables optionally logging of http requests and responses
func (*BitmaskMobile) SetIntroducer ¶
func (bm *BitmaskMobile) SetIntroducer(introducerUrl string) (err error)
func (*BitmaskMobile) SetResolveWithDoH ¶
func (bm *BitmaskMobile) SetResolveWithDoH(resolveWithDoH bool) error
func (*BitmaskMobile) SetSocksProxy ¶
func (bm *BitmaskMobile) SetSocksProxy(proxyUrl string) error
SetSocksProxy requires a URL in the socks5:// URL scheme
func (*BitmaskMobile) SetStunServers ¶
func (bm *BitmaskMobile) SetStunServers(servers string) (err error)
SetStunServers sets stun servers used for IP lookup and expects a comma separated list of <ip/addr>:<port> entries
func (*BitmaskMobile) SetUseTls ¶
func (bm *BitmaskMobile) SetUseTls(useTls bool) error
Source Files
¶
- bitmaskmobile.go
Click to show internal directories.
Click to hide internal directories.